canvas		{ border:0; background-color: white; }
td.mousebox	{ vertical-align: top; }
td.mbh		{ height: 16pt; }
td.mb0		{ text-align: left; font-size: smaller; width: 20px; padding-left: 15px;
		  color:#000; background-color: #EEE}
td.mb1		{ text-align: left; font-size: smaller; width: 80px; padding-left: 15px;
		  color:#070; background-color: #EEE}
td.icon		{ width:  16px; height: 16px; font-size: 14px; text-align: right;
		  background-color: #EEE}
td.blank	{ height: 16px; font-size: 12pt; text-align: right;
		  background-color: #EEE}
.icon-image	{ float:right; margin: 0 0 0 0; }
.noborder	{ border: 0; vertical-align: text-top; }
table.mbleft	{ border-collapse: collapse; border: 0; margin-left: auto; margin-right: auto; }
table.mbright	{ border-collapse: collapse; border: 0; margin-left: 0; margin-right: auto; }
table.mbunder	{ border-collapse: collapse; border: 0; margin-left: auto; margin-right: auto; }
table.plot	{ border-collapse: collapse; border: 0; margin-left: auto; margin-right: auto; }
table.mousebox	{ border-collapse: collapse; margin-left: 0; margin-right: 10px; border: 0; }
div.gnuplot	{ background-color: white; }
